@@ -258,3 +258,63 @@ class EsHelper:
             "route_key": route_key,
         }, find_condition=params)
         return res
+
+    def sync_delete_one(self, route_key, id):
+        path = f"/{route_key}/{id}"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_delete(url=url)
+        return res
+
+    def sync_delete_data(self, route_key, params=[]):
+        path = f"/{route_key}/_delete_by_query"
+        url = self.pool.format_url(path)
+        data = {
+            "query": {
+                "bool": {
+                    "must": params
+                }
+            }
+        }
+        res = self.pool.format_es_delete(url=url, data=data)
+        return res
+
+    def sync_update_data(self, route_key, params, new_data: dict):
+        path = f"/{route_key}/_update_by_query"
+        url = self.pool.format_url(path)
+        data = {
+            "query": {
+                "bool": {
+                    "must": params
+                }
+            },
+            "script": {
+                "source": ""
+            }
+        }
+        source = ""
+        for k, v in new_data.items():
+            source += f'ctx._source.{k}={v};'
+        data["script"]["source"] = source
+        res = self.pool.format_es_post(url=url, body=data)
+        return res
+
+    def sync_update_one(self, route_key, id, data):
+        path = f"/{route_key}/{id}/_update"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=data)
+        return res
+
+    def sync_insert_one(self, route_key, data, id=None):
+        if id:
+            path = f"/{route_key}/{id}"
+        else:
+            path = f"/{route_key}"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=data)
+        return res
+
+    def sync_insert_data(self, route_key, data):
+        path = f"/{route_key}/_bulk"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=data)
+        return res
