@@ -13,8 +13,8 @@ class SqlAlchemyHelper:
         else:
             self.pool = pool
 
-    def make_session(self):
-        session = Session(self.pool, autocommit=True)
+    def make_session(self, autocommit=True, **kwargs):
+        session = Session(self.pool, autocommit=autocommit, **kwargs)
         return session
 
 
